OC.L10N.register(
    "core",
    {
    "Please select a file." : "Seleziona un file.",
    "File is too big" : "Il file è troppo grande",
    "The selected file is not an image." : "Il file selezionato non è un'immagine.",
    "The selected file cannot be read." : "Il file selezionato non può essere letto.",
    "The file was uploaded" : "Il file è stato caricato",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Il file caricato supera la direttiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
    "The file was only partially uploaded" : "Il file è stato caricato solo parzialmente",
    "No file was uploaded" : "Nessun file caricato",
    "Missing a temporary folder" : "Manca una cartella temporanea",
    "Could not write file to disk" : "Impossibile scrivere il file su disco",
    "A PHP extension stopped the file upload" : "Un'estensione PHP ha fermato il caricamento del file",
    "Invalid file provided" : "File fornito non valido ",
    "No image or file provided" : "Non è stata fornita alcun immagine o file",
    "Unknown filetype" : "Tipo di file sconosciuto",
    "An error occurred. Please contact your admin." : "Si è verificato un errore. Contatta il tuo amministratore.",
    "Invalid image" : "Immagine non valida",
    "No temporary profile picture available, try again" : "Nessuna immagine di profilo provvisoria disponibile, riprova",
    "No crop data provided" : "Non sono stati forniti dati di ritaglio",
    "No valid crop data provided" : "Non sono stati forniti dati di ritaglio validi",
    "Crop is not square" : "Il ritaglio non è quadrato",
    "State token does not match" : "Il token di stato non corrisponde",
    "Invalid app password" : "Password dell'applicazione non valida",
    "Could not complete login" : "Impossibile completare l'accesso",
    "Your login token is invalid or has expired" : "Il tuo token di accesso non è valido o è scaduto",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Questa versione della community di Nextcloud non è supportata e le notifiche push sono limitate.",
    "Login" : "Accedi",
    "Please try again" : "Riprova",
    "Password reset is disabled" : "Ripristino password disabilitato",
    "Could not reset password because the token is expired" : "Impossibile reimpostare la password poiché il token è scaduto",
    "Could not reset password because the token is invalid" : "Impossibile reimpostare la password poiché il token non è valido",
    "Password is too long. Maximum allowed length is 469 characters." : "La password è troppo lunga. La lunghezza massima consentita è di 469 caratteri.",
    "%s password reset" : "Ripristino password di %s",
    "Password reset" : "Ripristino password",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Fai clic sul pulsante seguente per reimpostare la tua password. Se non hai richiesto la reimpostazione della password, ignora questo messaggio.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Fai clic sul collegamento seguente per reimpostare la tua password. Se non hai richiesto la reimpostazione della password, ignora questo messaggio.",
    "Reset your password" : "Ripristina la password",
    "Nextcloud Server" : "Server Nextcloud",
    "Some of your link shares have been removed" : "Alcune delle tue condivisioni tramite collegamento sono state rimosse",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "A causa di un bug di sicurezza abbiamo rimosso alcune delle tue condivisioni tramite collegamento. Vedi il collegamento per ulteriori informazioni.",
    "The user limit of this instance is reached." : "Il limite di utenti di questa istanza è stato raggiunto.",
    "Learn more ↗" : "Ulteriori informazioni ↗",
    "Preparing update" : "Preparazione dell'aggiornamento",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Fase di riparazione:",
    "Repair info:" : "Informazioni di riparazione:",
    "Repair warning:" : "Avviso di riparazione",
    "Repair error:" : "Errore di riparazione:",
    "Turned on maintenance mode" : "Modalità di manutenzione attivata",
    "Turned off maintenance mode" : "Modalità di manutenzione disattivata",
    "Maintenance mode is kept active" : "La modalità di manutenzione è lasciata attiva",
    "Updating database schema" : "Aggiornamento schema database",
    "Updated database" : "Database aggiornato",
    "Update app \"%s\" from App Store" : "Aggiorna l'applicazione \"%s\" dal negozio delle applicazioni",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Controllo che lo schema del database di %s possa essere aggiornato (ciò potrebbe richiedere molto tempo in base alla dimensione del database)",
    "Updated \"%1$s\" to %2$s" : "Aggiornato \"%1$s\" a %2$s",
    "Set log level to debug" : "Imposta il livello del log per il debug",
    "Reset log level" : "Ripristina il livello del log",
    "Starting code integrity check" : "Avvio del controllo di integrità del codice",
    "Finished code integrity check" : "Controllo di integrità del codice terminato",
    "%s (incompatible)" : "%s (incompatibile)",
    "The following apps have been disabled: %s" : "Le seguenti applicazioni sono state disabilitate: %s",
    "Already up to date" : "Già aggiornato",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Il tuo server web non è configurato correttamente per consentire la sincronizzazione dei file, poiché l'interfaccia WebDAV sembra essere danneggiata.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Il tuo server web non è configurato correttamente per risolvere \"{url}\". Ulteriori informazioni sono disponibili nella nostra {linkstart}documentazione ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Il tuo server non è configurato correttamente per risolvere \"{url}\". Ciò è probabilmente legato a una configurazione del server che non è stata aggiornata per fornire direttamente questa cartella. Confronta la tua configurazione con le regole di rewrite fornite in \".htaccess\" per Apache o quella fornita nella documentazione di Nginx alla sua {linkstart}pagina di documentazione ↗{linkend}. Su Nginx di solito sono le righe che iniziano con \"location ~\" quelle da aggiornare.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Il tuo server web non è configurato correttamente per fornire file .woff2. Questo è solitamente un problema con la configurazione di Nginx. Per Nextcloud 15 richiede una modifica per fornire anche i file .woff2. Confronta la tua configurazione di Nginx con la configurazione consigliata nella nostra {linkstart}documentazione ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP non sembra essere configurato correttamente per interrogare le variabili d'ambiente di sistema. Il test con getenv(\"PATH\") restituisce solo una risposta vuota.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Controlla la {linkstart}documentazione di installazione ↗{linkend} per le note di configurazione di PHP e la configurazione del tuo server, in particolare quando utilizzi php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configurazione di sola lettura è stata abilitata. Ciò impedisce l'impostazione di alcune configurazioni tramite l'interfaccia web. Inoltre, i file devono essere resi scrivibili manualmente per ogni aggiornamento.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Non hai ancora impostato o verificato la configurazione del tuo server di posta elettronica. Vai nelle {mailSettingsStart}Impostazioni di base{mailSettingsEnd} per configurarla. Successivamente, usa il pulsante \"Invia email\" sotto al modulo per verificare le impostazioni.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Il tuo database non è in esecuzione con il livello di isolamento delle transazioni \"READ COMMITTED\". Ciò può causare problemi quando diverse azioni sono eseguite in parallelo.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Il modulo PHP 'fileinfo' non è presente. Consigliamo vivamente di abilitare questo modulo per ottenere risultati migliori con il rilevamento dei tipi MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Il blocco del file transazionale è disattivato, ciò potrebbe comportare problemi di race condition. Attiva \"filelocking.enabled\" nel config.php per evitare questi problemi. Vedi la {linkstart}documentazione ↗{linkend} per ulteriori informazioni.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Assicurati di impostare l'opzione \"overwrite.cli.url\" nel tuo file config.php all'URL che i tuoi utenti usano abitualmente per accedere a questo Nextcloud. Consiglio: \"{suggestedOverwriteCliURL}\". Altrimenti potrebbero esserci problemi con la generazione dell'URL via cron. (È possibile comunque che l'URL consigliato non sia l'URL che i tuoi utenti usano abitualmente per accedere a questo Nextcloud. È meglio controllarlo due volte in ogni caso.)",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "La tua installazione non ha una regione telefonica predefinita impostata. Ciò è necessario per poter convalidare i numeri di telefono nelle impostazioni del profilo senza un codice nazionale. Per consentire i numeri senza un codice nazionale, aggiungi \"default_phone_region\" con il rispettivo {linkstart}codice ISO 3166-1 ↗{linkend} della regione desiderata al file di configurazione.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Non è stato possibile eseguire il job di cron tramite CLI. Sono apparsi i seguenti errori tecnici:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "L'ultimo processo in background è durato {relativeTime}. Qualcosa non va. {linkstart}Controlla le impostazioni del processi in background ↗{linkend}.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Questo server non ha una connessione a Internet funzionante: diversi dispositivi finali non sono raggiungibili. Ciò significa che alcune delle funzionalità come il montaggio di archivi esterni, le notifiche degli aggiornamenti o l'installazione di applicazioni di terze parti non funzioneranno. Anche l'accesso remoto ai file e l'invio di email di notifica potrebbero non funzionare. Attiva la connessione a Internet del server se desideri disporre di tutte le funzionalità.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Non è stata configurata alcuna cache di memoria. Per migliorare le prestazioni configura memcache, se disponibile. Ulteriori informazioni sono disponibili nella nostra {linkstart}documentazione ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nessuna fonte di casualità trovata da PHP e ciò è vivamente sconsigliato per motivi di sicurezza. Ulteriori informazioni sono disponibili nella {linkstart}documentazione ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Stai eseguendo attualmente PHP {version}. Aggiorna la tua versione di PHP per trarre vantaggio dagli {linkstart}aggiornamenti in termini di prestazioni e sicurezza forniti dal PHP Group ↗{linkend} non appena la tua distribuzione la supporta.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "La configurazione delle intestazioni del proxy inverso non è corretta, o stai effettuando l'accesso a Nextcloud da un proxy affidabile. In caso diverso, questo è un problema di sicurezza e può consentire a un attaccante di falsificare il suo indirizzo IP, rendendolo visibile a Nextcloud. Ulteriori informazioni sono disponibili nella {linkstart}documentazione ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached è configurato come cache distribuita, ma è installato il modulo PHP \"memcache\" errato. \\OC\\Memcache\\Memcached supporta solo \"memcached\" e non \"memcache\". Vedi il {linkstart}wiki di memcached per informazioni su entrambi i moduli ↗{linkend}..",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Alcuni file non hanno superato il controllo di integrità. Ulteriori informazioni su come risolvere questo problema sono disponibili nella nostra {linkstart1}documentazione ↗{linkend}. ({linkstart2}Elenco dei file non validi… {linkend} / {linkstart3}Nuova scansione…{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "Il modulo PHP OPcache non è configurato correttamente. Controlla la {linkstart}documentazione ↗{linkend} per maggiori informazioni.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La funzione PHP \"set_time_limit\" non è disponibile. Ciò potrebbe comportare l'interruzione di script durante l'esecuzione, compromettendo la tua installazione. Ti consigliamo vivamente di abilitare questa funzione.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "La tua versione di PHP non supporta FreeType. Ciò causerà problemi con le immagini dei profili e con l'interfaccia delle impostazioni.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Indice mancante \"{indexName}\" nella tabella \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Nel database mancano alcuni indici. Poiché l'aggiunta di indici su tabelle grandi può richiedere del tempo, non sono stati aggiunti automaticamente. Eseguendo \"occ db:add-missing-indices\", gli indici mancanti possono essere aggiunti manualmente mentre l'istanza è in esecuzione. Una volta che gli indici sono stati aggiunti, le interrogazioni a tali tabelle sono solitamente più veloci.",
    "Missing primary key on table \"{tableName}\"." : "Chiave primaria mancante nella tabella \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Nel database mancano alcune chiavi primarie. Poiché l'aggiunta di chiavi primarie su tabelle grandi può richiedere del tempo, non sono state aggiunte automaticamente. Eseguendo \"occ db:add-missing-primary-keys\", quelle chiavi mancanti possono essere aggiunte manualmente mentre l'istanza è in esecuzione.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Colonna opzionale \"{columnName}\" mancante nella tabella \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Nel database mancano alcune colonne opzionali. Poiché l'aggiunta di colonne su tabelle grandi può richiedere del tempo, non sono state aggiunte automaticamente. Eseguendo \"occ db:add-missing-columns\", le colonne mancanti possono essere aggiunte manualmente mentre l'istanza è in esecuzione. Una volta che le colonne sono state aggiunte, alcune funzionalità potrebbero migliorare i tempi di risposta o l'usabilità.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Su questa istanza mancano alcuni moduli PHP consigliati. Per prestazioni migliorate e migliore compatibilità, è vivamente consigliato di installarli.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Il modulo PHP \"imagick\" non è attivato sebbene l'app dei temi lo sia. Affinché la generazione di favicon funzioni bene, devi installare ed attivare questo modulo.",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "I moduli PHP \"gmp\" e/o \"bcmath\" non sono attivati. Se usi l'autenticazione senza password WebAuthn, questi moduli sono necessari.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Al modulo php-imagick manca il supporto SVG. Per una migliore compatibilità si consiglia di installarlo.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "In alcune colonne del database manca una conversione in big int. Poiché la modifica dei tipi di colonna su tabelle di grandi dimensioni potrebbe richiedere del tempo, non sono state modificate automaticamente. Eseguendo \"occ db:convert-filecache-bigint\" è possibile applicare manualmente le modifiche in sospeso. Questa operazione deve essere eseguita mentre l'istanza è offline. Per ulteriori dettagli leggi {linkstart} la pagina della documentazione relativa a questo ↗{linkend}.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite è utilizzato attualmente come database. Per installazioni più grandi consigliamo di passare a un motore di database diverso.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Consigliato particolarmente quando si utilizza il client desktop per la sincronizzazione dei file.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Per migrare a un altro database usa lo strumento da riga di comando: \"occ db:convert-type\", oppure consulta la {linkstart}documentazione ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "Il limite di memoria di PHP è inferiore al valore consigliato di 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Alcune applicazioni sono di proprietà di un utente diverso da quello del server web. Questo potrebbe verificarsi se le applicazioni sono state installate manualmente. Controlla i permessi delle cartelle delle seguenti applicazioni:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL è utilizzato come database, ma non supporta caratteri di 4 byte. Per poter gestire i caratteri da 4 byte (come le emoji) senza problemi nei nomi dei file o nei commenti, si consiglia,  ad esempio,  di abilitare il supporto per i 4 byte in MySQL. Per ulteriori dettagli, leggi {linkstart}la pagina di documentazione relativa{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Questa istanza utilizza un object store basato su S3 come archiviazione primaria. I file caricati sono memorizzati temporaneamente sul server e perciò è consigliato avere 50 GB di spazio libero nella cartella temporanea di PHP. Controlla i log per i dettagli completi sul percorso e sullo spazio disponibile. Per migliorare questo aspetto, cambia la cartella temporanea nel file php.ini o assegna altro spazio in quel percorso.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "La cartella temporanea di questa istanza punta ad una cartella inesistente oppure non scrivibile.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Stai accedendo alla tua istanza tramite una connessione sicura, tuttavia la tua istanza sta generando URL non sicuri. Questo molto probabilmente significa che sei dietro un proxy inverso e le variabili di configurazione di sovrascrittura non sono impostate correttamente. Leggi {linkstart}la pagina della documentazione relativa ↗{linkend}.",
    "Error occurred while checking server setup" : "Si è verificato un errore durante il controllo della configurazione del server",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Per ulteriori dettagli, leggi la {linkstart}documentazione ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "La cartella dei dati e i tuoi file sono probabilmente accessibili da Internet. Il file .htaccess non funziona. Ti consigliamo vivamente di configurare il server in modo che la cartella dei dati non sia più accessibile o di spostare la cartella fuori dalla radice del server web.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "L'intestazione HTTP \"{header}\" non è configurata come \"{expected}\". \nQuesto è un potenziale rischio di sicurezza o di riservatezza, e noi consigliamo di modificare questa impostazione.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "L'intestazione HTTP \"{header}\" non è configurata come \"{expected}\". Alcune funzionalità potrebbero non funzionare correttamente e ti consigliamo di modificare questa impostazione.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "L'intestazione HTTP \"{header}\" non è impostata a \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" o \"{val5}\". Ciò può far trapelare informazioni sul referer. Vedi la {linkstart}W3C Recommendation ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "L'intestazione HTTP \"Strict-Transport-Security\" non è configurata con un valore di almeno \"{seconds}\" secondi. Per migliorare la sicurezza, consigliamo di abilitare HSTS come descritto nei {linkstart}consigli sulla sicurezza ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Sei connesso a questo sito in modo non sicuro tramite HTTP. Ti consigliamo vivamente di configurare il tuo server per richiedere invece HTTPS, come descritto nei {linkstart}consigli sulla sicurezza ↗{linkend}.",
    "unknown text" : "testo sconosciuto",
    "Hello world!" : "Ciao mondo!",
    "sunny" : "soleggiato",
    "Hello {name}, the weather is {weather}" : "Ciao {name}, il tempo è {weather}",
    "Hello {name}" : "Ciao {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Questi sono i tuoi risultati di ricerca<script>alert(1)</script></strong>",
    "new" : "nuovo",
    "_download %n file_::_download %n files_" : ["scarica %n file","scarica %s file","scarica %s file"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "L'aggiornamento è in corso, l'abbandono di questa pagina potrebbe interrompere il processo in alcuni ambienti.",
    "Update to {version}" : "Aggiorna a {version}",
    "An error occurred." : "Si è verificato un errore.",
    "Please reload the page." : "Ricarica la pagina.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "L'aggiornamento non è riuscito. Per ulteriori informazioni <a href=\"{url}\">controlla l'articolo del nostro forum</a> che riguarda questo problema.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "L'aggiornamento non è riuscito. Segnala il problema alla <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunità di Nextcloud </a>.",
    "Continue to {productName}" : "Continua in {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} in %n secondo.","L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} %n secondi.","L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} %n secondi."],
    "More apps" : "Altre applicazioni",
    "Currently open" : "Attualmente aperto",
    "Log in" : "Accedi",
    "Logging in …" : "Accesso in corso...",
    "Server side authentication failed!" : "Autenticazione lato server non riuscita!",
    "Please contact your administrator." : "Contatta il tuo amministratore di sistema.",
    "An internal error occurred." : "Si è verificato un errore interno.",
    "Please try again or contact your administrator." : "Prova ancora o contatta il tuo amministratore.",
    "Account name or email" : "Nome utente o email",
    "Password" : "Password",
    "Log in to {productName}" : "Accedi a {productName}",
    "Wrong username or password." : "Nome utente o password errati.",
    "User disabled" : "Disabilitato dall'utente",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Abbiamo rilevato molti tentativi di autenticazione non riusciti dal tuo indirizzo IP. Di conseguenza, il prossimo tentativo è ritardato di 30 secondi.",
    "Username or email" : "Nome utente o email",
    "Your account is not setup for passwordless login." : "Il tuo account non è configurato per l'accesso senza password.",
    "Browser not supported" : "Browser non supportato",
    "Passwordless authentication is not supported in your browser." : "L'autenticazione senza password non è supportata dal tuo browser. ",
    "Your connection is not secure" : "La tua connessione non è sicura",
    "Passwordless authentication is only available over a secure connection." : "L'autenticazione senza password è disponibile solo su una connessione sicura.",
    "Reset password" : "Ripristina la password",
    "Couldn't send reset email. Please contact your administrator." : "Impossibile inviare l'email di reimpostazione. Contatta il tuo amministratore.",
    "Password cannot be changed. Please contact your administrator." : "La password non può essere cambiata. Contatta il tuo amministratore.",
    "Back to login" : "Torna alla schermata di accesso",
    "New password" : "Nuova password",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "I tuoi file sono cifrati. Non sarà più possibile recuperare i tuoi dati una volta che la password sarà reimpostata. Se non sei sicuro, contatta l'amministratore prima di proseguire. Vuoi davvero continuare?",
    "I know what I'm doing" : "So cosa sto facendo",
    "Resetting password" : "Ripristino password",
    "Recommended apps" : "Applicazioni consigliate",
    "Loading apps …" : "Caricamento applicazioni…",
    "Could not fetch list of apps from the App Store." : "Impossibile scaricare l'elenco delle applicazioni dal negozio delle applicazioni.",
    "Installing apps …" : "Installazione applicazioni…",
    "App download or installation failed" : "Scaricamento o installazione dell'applicazione non riuscito",
    "Cannot install this app because it is not compatible" : "Impossibile installare questa applicazione poiché non è compatibile",
    "Cannot install this app" : "Impossibile installare questa applicazione",
    "Skip" : "Salta",
    "Install recommended apps" : "Installa applicazioni consigliate",
    "Schedule work & meetings, synced with all your devices." : "Pianificare lavoro e riunioni, sincronizzati con tutti i tuoi dispositivi.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Tieni i tuoi colleghi e i tuoi amici in un posto proteggendo le loro Informazioni personali.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Applicazione di posta elettronica semplice e ben integrata con File, Contatti e Calendario.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, videochiamate, condivisione schermo, riunioni in linea e conferenze web – nel tuo browser e con le applicazioni mobili.",
    "Search contacts" : "Cerca nei contatti",
    "Forgot password?" : "Hai dimenticato la password?",
    "Log in with a device" : "Accedi con un dispositivo",
    "Back" : "Indietro",
    "Login form is disabled." : "Il modulo di accesso è disabilitato.",
    "Edit Profile" : "Modifica il profilo",
    "The headline and about sections will show up here" : "Le sezioni del titolo e delle informazioni verranno mostrate qui",
    "You have not added any info yet" : "Non hai ancora aggiunto alcuna informazione",
    "{user} has not added any info yet" : "{user} non ha ancora aggiunto alcuna informazione",
    "Error opening the user status modal, try hard refreshing the page" : "Errore nell'apertura dello stato utente, prova a ricaricare la pagina",
    "Reset search" : "Ripristina ricerca",
    "Start search" : "Avvia ricerca",
    "Search for {name} only" : "Cerca solo {name}",
    "Start typing to search" : "Inizia a digitare per cercare",
    "Loading more results …" : "Caricamento di più risultati...",
    "Load more results" : "Carica più risultati",
    "Search" : "Cerca",
    "No results for {query}" : "Nessun risultato per {query}",
    "An error occurred while searching for {type}" : "Si è verificato un errore durante la ricerca di {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Digita {minSearchLength} carattere o più per cercare","Digita {minSearchLength} caratteri o più per cercare","Digita {minSearchLength} caratteri o più per cercare"],
    "This browser is not supported" : "Questo browser non è supportato",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Il tuo browser non è supportato. Effettua l'upgrade a una versione più recente o supportata.",
    "Continue with this unsupported browser" : "Prosegui con questo browser non supportato",
    "Supported versions" : "Versioni supportate",
    "{name} version {version} and above" : "{name} versione {version} e successive",
    "Open settings menu" : "Apri il menu impostazioni",
    "Settings menu" : "Menu delle impostazioni",
    "Search {types} …" : "Cerca {types}...",
    "Settings" : "Impostazioni",
    "Could not load your contacts" : "Impossibile caricare i tuoi contatti",
    "Search contacts …" : "Cerca contatti...",
    "No contacts found" : "Nessun contatto trovato",
    "Show all contacts …" : "Mostra tutti i contatti...",
    "Install the Contacts app" : "Installa l'applicazione Contatti",
    "Loading your contacts …" : "Caricamento dei tuoi contatti...",
    "Looking for {term} …" : "Ricerca di {term} in corso...",
    "No" : "No",
    "Yes" : "Sì",
    "No files in here" : "Qui non c'è alcun file",
    "New folder" : "Nuova cartella",
    "No more subfolders in here" : "Qui non ci sono altre sottocartelle",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "\"/\" is not allowed inside a file name." : "\"/\" non è consentito nel nome di un file.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" non è un tipo di file consentito",
    "{newName} already exists" : "{newName} esiste già",
    "Choose" : "Scegli",
    "Copy" : "Copia",
    "Move" : "Sposta",
    "Error loading file picker template: {error}" : "Errore durante il caricamento del modello del selettore file: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Errore durante il caricamento del modello di messaggio: {error}",
    "read-only" : "sola lettura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} file in conflitto","{count} file in conflitto","{count} file in conflitto"],
    "One file conflict" : "Un file in conflitto",
    "New Files" : "File nuovi",
    "Already existing files" : "File già esistenti",
    "Which files do you want to keep?" : "Quali file vuoi mantenere?",
    "If you select both versions, the copied file will have a number added to its name." : "Se selezioni entrambe le versioni, sarà aggiunto un numero al nome del file copiato.",
    "Cancel" : "Annulla",
    "Continue" : "Continua",
    "(all selected)" : "(tutti i selezionati)",
    "({count} selected)" : "({count} selezionati)",
    "Error loading file exists template" : "Errore durante il caricamento del modello del file esistente",
    "Show list view" : "Commuta la vista a lista",
    "Show grid view" : "Commuta la vista a griglia",
    "Pending" : "In corso",
    "Home" : "Pagina principale",
    "Copy to {folder}" : "Copia in {folder}",
    "Move to {folder}" : "Sposta in {folder}",
    "Saving …" : "Salvataggio…",
    "Authentication required" : "Autenticazione richiesta",
    "This action requires you to confirm your password" : "Questa azione richiede la conferma della tua password",
    "Confirm" : "Conferma",
    "Failed to authenticate, try again" : "Autenticazione non riuscita, prova ancora",
    "seconds ago" : "secondi fa",
    "Connection to server lost" : "Connessione al server interrotta",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema durante il caricamento della pagina, aggiornamento tra %n secondo","Problema durante il caricamento della pagina, aggiornamento tra %n secondi","Problema durante il caricamento della pagina, aggiornamento tra %n secondi"],
    "Add to a project" : "Aggiungi a un progetto",
    "Show details" : "Mostra dettagli",
    "Hide details" : "Nascondi dettagli",
    "Rename project" : "Rinomina progetto",
    "Failed to rename the project" : "Rinomina progetto non riuscita",
    "Failed to create a project" : "Creazione progetto non riuscita",
    "Failed to add the item to the project" : "Aggiunta dell'elemento al progetto non riuscita",
    "Connect items to a project to make them easier to find" : "Collega elementi a un progetto per poterli trovare più facilmente",
    "Type to search for existing projects" : "Digita per cercare progetti esistenti",
    "New in" : "Nuovo in",
    "View changelog" : "Visualizza le novità",
    "Very weak password" : "Password molto debole",
    "Weak password" : "Password debole",
    "So-so password" : "Password così-così",
    "Good password" : "Password buona",
    "Strong password" : "Password forte",
    "No action available" : "Nessuna azione disponibile",
    "Error fetching contact actions" : "Errore durante il recupero delle azioni dei contatti",
    "Non-existing tag #{tag}" : "Etichetta #{tag} inesistente",
    "Restricted" : "Limitato",
    "Invisible" : "Invisibile",
    "Delete" : "Elimina",
    "Rename" : "Rinomina",
    "Collaborative tags" : "Etichette collaborative",
    "No tags found" : "Nessuna etichetta trovata",
    "Personal" : "Personale",
    "Users" : "Utenti",
    "Apps" : "Applicazioni",
    "Admin" : "Admin",
    "Help" : "Aiuto",
    "Access forbidden" : "Accesso negato",
    "Profile not found" : "Profilo non trovato",
    "The profile does not exist." : "Il profilo non esiste.",
    "Back to %s" : "Torna a %s",
    "Page not found" : "Pagina non trovata",
    "The page could not be found on the server." : "Impossibile trovare la pagina sul server.",
    "Too many requests" : "Troppe richieste",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Sono arrivate troppe richieste dalla tua rete. Riprova più tardi o contatta il tuo amministratore se questo è un errore.",
    "Error" : "Errore",
    "Previous" : "Precedente",
    "Internal Server Error" : "Errore interno del server",
    "The server was unable to complete your request." : "Il server non è stato in grado di completare la tua richiesta.",
    "If this happens again, please send the technical details below to the server administrator." : "Se ciò si verifca nuovamente, invia i seguenti dettagli tecnici all'amministratore del server.",
    "More details can be found in the server log." : "Ulteriori dettagli sono disponibili nel log del server.",
    "Technical details" : "Dettagli tecnici",
    "Remote Address: %s" : "Indirizzo remoto: %s",
    "Request ID: %s" : "ID richiesta: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Codice: %s",
    "Message: %s" : "Messaggio: %s",
    "File: %s" : "File: %s",
    "Line: %s" : "Riga: %s",
    "Trace" : "Traccia",
    "Security warning" : "Avviso di sicurezza",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La cartella dei dati e i file sono probabilmente accessibili da Internet poiché il file .htaccess non funziona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per informazioni su come configurare correttamente il tuo server, vedi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentazione</a>.",
    "Create an <strong>admin account</strong>" : "Crea un <strong>account amministratore</strong>",
    "Username" : "Nome utente",
    "Show password" : "Mostra password",
    "Toggle password visibility" : "Commuta la visibilità delle password",
    "Storage & database" : "Archiviazione e database",
    "Data folder" : "Cartella dati",
    "Configure the database" : "Configura il database",
    "Only %s is available." : "È disponibile solo %s.",
    "Install and activate additional PHP modules to choose other database types." : "Installa e attiva i moduli PHP aggiuntivi per scegliere gli altri tipi di database.",
    "For more details check out the documentation." : "Per ulteriori dettagli, leggi la documentazione.",
    "Database user" : "Utente del database",
    "Database password" : "Password del database",
    "Database name" : "Nome del database",
    "Database tablespace" : "Spazio delle tabelle del database",
    "Database host" : "Host del database",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Specifica il numero della porta insieme al nome host (ad es. localhost:5432).",
    "Performance warning" : "Avviso di prestazioni",
    "You chose SQLite as database." : "Hai scelto SQLite come database.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite dovrebbe essere scelto solo per istanze minimali e di sviluppo. Per la produzione, consigliamo un motore di database diverso.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se utilizzi client per la sincronizzazione dei file, l'uso di SQLite è sconsigliato.",
    "Install" : "Installa",
    "Installing …" : "Installazione …",
    "Need help?" : "Ti serve aiuto?",
    "See the documentation" : "Leggi la documentazione",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Sembra che tu stia tentando di reinstallare il tuo Nextcloud. Tuttavia, manca il file CAN_INSTALL dalla cartella config. Crea il file CAN_INSTALL nella cartella config per continuare.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Impossibile rimuovere il file CAN_INSTALL dalla cartella config. Rimuovi il file manualmente.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Questa applicazione richiede JavaScript per un corretto funzionamento. {linkstart}Abilita JavaScript{linkend} e ricarica la pagina.",
    "Skip to main content" : "Passa al contenuto principale",
    "Skip to navigation of app" : "Passa alla navigazione dell'applicazione",
    "Get your own free account" : "Ottieni il tuo account gratuito",
    "Go to %s" : "Vai a %s",
    "Confirm your password" : "Conferma la tua password",
    "Connect to your account" : "Connetti il tuo account",
    "Please log in before granting %1$s access to your %2$s account." : "Accedi prima di accordare a %1$s l'accesso al tuo account %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se non stai tentando di configurare un nuovo dispositivo o applicazione, qualcuno sta provando a ingannarti per ottenere l'accesso ai tuoi dati. In questo caso non procedere e contatta l'amministratore di sistema.",
    "App token" : "Token applicazione",
    "Grant access" : "Accorda accesso",
    "Alternative log in using app token" : "Accesso alternativo utilizzando il token dell'applicazione",
    "Account access" : "Accesso account",
    "Currently logged in as %1$s (%2$s)." : "Attualmente connesso come %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Stai per accordare a %1$s l'accesso al tuo account %2$s.",
    "Account connected" : "Account connesso",
    "Your client should now be connected!" : "Il client ora dovrebbe essere connesso!",
    "You can close this window." : "Puoi chiudere questa finestra.",
    "This share is password-protected" : "Questa condivisione è protetta da password",
    "The password is wrong or expired. Please try again or request a new one." : "La password è errata o scaduta. Riprova o richiedine una nuova.",
    "Please type in your email address to request a temporary password" : "Inserisci il tuo indirizzo email per richiedere una password temporanea",
    "Email address" : "Indirizzo email",
    "Password sent!" : "Password inviata!",
    "You are not authorized to request a password for this share" : "Non sei autorizzato a richiedere una password per questa condivisione",
    "Two-factor authentication" : "Autenticazione a due fattori",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La sicurezza migliorata è abilitata per il tuo account. Scegli un secondo fattore per l'autenticazione:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Impossibile caricare almeno uno dei metodi di autenticazione a due fattori. Contatta il tuo amministratore.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "L'autenticazione a due fattori è applicata, ma non è stata configurata nel tuo account. Contatta il tuo amministratore per assistenza.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "L'autenticazione a due fattori è applicata, ma non è stata configurata nel tuo account. Continua per configurare l'autenticazione a due fattori.",
    "Set up two-factor authentication" : "Configura l'autenticazione a due fattori",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "L'autenticazione a due fattori è applicata, ma non è stata configurata nel tuo account. Utilizza uno dei tuoi codici di backup per accedere o contatta il tuo amministratore per assistenza.",
    "Use backup code" : "Usa il codice di backup",
    "Cancel login" : "Annulla l'accesso",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "La sicurezza migliorata è applicata al tuo account. Scegli quale fornitore configurare:",
    "Error while validating your second factor" : "Errore durante la convalida del tuo secondo fattore",
    "Access through untrusted domain" : "Accedi tramite un dominio non attendibile",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Contatta il tuo amministratore. Se sei un amministratore, modifica l'impostazione \"trusted_domains\" in config/config.php come l'esempio disponibile in config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Ulteriori informazioni sulla configurazione sono disponibili nella %1$s documentazione %2$s.",
    "App update required" : "Aggiornamento dell'applicazione richiesto",
    "%1$s will be updated to version %2$s" : "%1$s sarà aggiornato alla versione %2$s",
    "The following apps will be updated:" : "Le seguenti applicazioni saranno aggiornate:",
    "These incompatible apps will be disabled:" : "Queste applicazioni incompatibili saranno disabilitate:",
    "The theme %s has been disabled." : "Il tema %s è stato disabilitato.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Assicurati di aver creato una copia di sicurezza del database, della cartella config e della cartella data prima di procedere. ",
    "Start update" : "Avvia l'aggiornamento",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per evitare timeout con installazioni di grandi dimensioni, puoi eseguire il comando che segue dalla cartella di installazione:",
    "Detailed logs" : "Log dettagliati",
    "Update needed" : "Aggiornamento necessario",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Utilizza lo strumento di aggiornamento da riga di comando perché hai un'istanza grande con più di 50 utenti.",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Utilizza lo strumento da riga di comando poiché l'aggiornamento automatico è disabilitato nel file config.php.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Per la guida, vedi la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentazione</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sono consapevole che, procedendo con l'aggiornamento tramite interfaccia web, esista il rischio che la richiesta possa scadere e causare perdite di dati, ma ho una copia di sicurezza e so come ripristinare la mia istanza in caso di problemi.",
    "Upgrade via web on my own risk" : "Aggiorna tramite web a mio rischio",
    "Maintenance mode" : "Modalità Manutenzione",
    "This %s instance is currently in maintenance mode, which may take a while." : "Questa istanza di %s è attualmente in manutenzione, potrebbe richiedere del tempo.",
    "This page will refresh itself when the instance is available again." : "Questa pagina si aggiornerà quando l'istanza sarà nuovamente disponibile.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contatta il tuo amministratore di sistema se questo messaggio persiste o appare inaspettatamente.",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Questa versione di Nextcloud della community non è supportata e le notifiche istantanee non sono disponibili.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: controllo della tabella %s",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Questa è la build della community di Nextcloud non supportata. Data la dimensione di questa istanza, non possono essere garantite le prestazioni, l'affidabilità e la scalabilità. Le notifiche push sono state disattivate per evitare di sovraccaricare il nostro servizio gratuito. Maggiori informazioni sui vantaggi di Nextcloud Enterprise su nextcloud.com/enterprise.",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 è l'ultima versione che supporta PHP 7.3. Nextcloud 24 richiede almeno PHP 7.4.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "L'intestazione HTTP \"{header}\" non contiene \"{expected}\". Questo è un potenziale rischio di sicurezza o di riservatezza, e consigliamo di modificare questa impostazione.",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Abbiamo inviato un messaggio di ripristino della password all'indirizzo di posta di questo account. Se non lo ricevi, controlla le cartelle della posta indesiderata o contatta il tuo amministratore locale.",
    "If it is not there ask your local administrator." : "Se non c'è, chiedi al tuo amministratore locale.",
    "Collaboratively edit office documents." : "Modifica documenti di Office collaborativa.",
    "Local document editing back-end used by the Collabora Online app." : "Il motore di modifica dei documenti locali utilizzato dall'applicazione Collabora Online.",
    "restricted" : "limitato",
    "invisible" : "invisibile",
    "File not found" : "File non trovato",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Il documento non può essere trovato sul server. Forse la condivisione è stata eliminata o è scaduta?",
    "More" : "Altro",
    "More apps menu" : "Menu delle altre applicazioni",
    "Contacts" : "Contatti",
    "Contacts menu" : "Menu dei contatti",
    "Setup two-factor authentication" : "Configura l'autenticazione a due fattori",
    "Press enter to start searching" : "Premi invio per avviare la ricerca"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
